#!/usr/bin/python
import sys
import hashlib
import time
import xml.sax
import thrift.protocol.TBinaryProtocol as TBinaryProtocol
import thrift.transport.THttpClient as THttpClient
import edam.userstore.UserStore as UserStore
import edam.userstore.constants as UserStoreConstants
import edam.limits.constants as LimitsConstants
import edam.notestore.NoteStore as NoteStore
import edam.type.ttypes as Types

#
# Configure these based on the API key you received from Evernote
#
username = sys.argv[1]
password = sys.argv[2]

consumerKey = sys.argv[3]
consumerSecret = sys.argv[4]

userStoreUri = "https://www.evernote.com/edam/user"
noteStoreUriBase = "http://www.evernote.com/edam/note/"

allNotes = False
if len(sys.argv) < 6:
  allNotes = True

userStoreHttpClient = THttpClient.THttpClient(userStoreUri)
userStoreProtocol = TBinaryProtocol.TBinaryProtocol(userStoreHttpClient)
userStore = UserStore.Client(userStoreProtocol)

authResult = userStore.authenticate(username, password,
                                    consumerKey, consumerSecret)
user = authResult.user
authToken = authResult.authenticationToken

noteStoreUri =  noteStoreUriBase + user.shardId
noteStoreHttpClient = THttpClient.THttpClient(noteStoreUri)
noteStoreProtocol = TBinaryProtocol.TBinaryProtocol(noteStoreHttpClient)
noteStore = NoteStore.Client(noteStoreProtocol)

notebooks = noteStore.listNotebooks(authToken)
bookGUIDs = {}
for notebook in notebooks:
  bookGUIDs[notebook.name] = notebook.guid
  
sortedBooknames = bookGUIDs.keys()
sortedBooknames.sort()
for notebook in sortedBooknames:
  if allNotes or notebook == sys.argv[5]:
    filter = NoteStore.NoteFilter()
    filter.notebookGuid = bookGUIDs[notebook]
    filter.order = Types.NoteSortOrder.UPDATED
    filter.ascending = False
    notes = noteStore.findNotes(authToken, filter, 0, LimitsConstants.EDAM_USER_NOTES_MAX)
    
    for note in notes.notes:
      title = note.title
      contents = noteStore.getNoteContent(authToken,note.guid)
      #contents = contents.split("<en-note>")
      #contents = contents[1].split("</en-note>")
      #contents = contents[0].replace('<en-todo>', '[&nbsp;&nbsp;] ')
      contents = contents.replace('<en-todo>', '[&nbsp;&nbsp;] ')
      contents = contents.replace('<en-todo/>', '[&nbsp;&nbsp;] ')
      contents = contents.replace('<en-todo />', '[&nbsp;&nbsp;] ')
      contents = contents.replace('<en-todo checked="true">', '[x] ')
      contents = contents.replace('<en-todo checked="true"/>', '[x] ')
      contents = contents.replace('<en-todo checked="true" />', '[x] ')
      contents = contents.replace('</en-todo>', '')
      contents = contents.replace('<br />', '<br>')
      contents = contents.replace('<br/>', '<br>')
      contents = contents.replace('<br clear="none" />', '<br>')
      contents = contents.replace('<br clear="none"/>', '<br>')
      
      print "Start Note|%s|%s" % (notebook,title)
      print contents.strip()
      print "End Note"
